# Generated by Django 3.2.18 on 2023-02-15 13:52

import django.core.validators
from django.db import migrations
from django.db.models import Q


def add_repository_labels(apps, schema_editor):
    """Add labels to repositories."""

    # Add hide_from_search label to staging, rejected, inbound and synclist repos
    # Add pipeline=staging,rejected,approved to staging, rejected and published repos
    AnsibleRepository = apps.get_model('ansible', 'AnsibleRepository')
    AnsibleDistribution = apps.get_model('ansible', 'AnsibleDistribution')

    AnsibleRepository.objects.filter(
        Q(name__startswith="inbound-") | Q(name__endswith="-synclist")
    ).update(pulp_labels = {"hide_from_search": ""})

    # some of the earlier versions of hub have a different name for the repositories,
    # so we're going to use their distribution base path's since those are more reliable

    repo = AnsibleDistribution.objects.get(base_path="published").repository
    repo.pulp_labels={"pipeline": "approved"}
    repo.save()

    repo = AnsibleDistribution.objects.get(base_path="rejected").repository
    repo.pulp_labels={"pipeline": "rejected", "hide_from_search": ""}
    repo.save()

    repo = AnsibleDistribution.objects.get(base_path="staging").repository
    repo.pulp_labels={"pipeline": "staging", "hide_from_search": ""}
    repo.save()


class Migration(migrations.Migration):

    dependencies = [
        ('galaxy', '0035_aiindexdenylist'),
        ('core', '0098_pulp_labels'),
    ]

    operations = [
        migrations.RunPython(
            code=add_repository_labels,
            reverse_code=migrations.RunPython.noop
        )
    ]
